@@ -6,7 +6,6 @@ from __future__ import annotations
 import heapq
 from math import isnan
 from typing import (
-    TYPE_CHECKING,
     Any,
     Callable,
     Collection,
@@ -504,9 +503,6 @@ def extract(
     worst_score, optimal_score = _get_scorer_flags_py(scorer, kwargs)
     lowest_score_worst = optimal_score > worst_score
 
-    if limit is None:
-        limit = len(choices)
-
     result_iter = extract_iter(
         query,
         choices,
@@ -515,6 +511,10 @@ def extract(
         score_cutoff=score_cutoff,
         **kwargs,
     )
+
+    if limit is None:
+        return sorted(result_iter, key=lambda i: i[1], reverse=lowest_score_worst)
+
     if lowest_score_worst:
         return heapq.nlargest(limit, result_iter, key=lambda i: i[1])
     return heapq.nsmallest(limit, result_iter, key=lambda i: i[1])
@@ -522,7 +522,7 @@ def extract(
 
 try:
     import numpy as np
-except:
+except BaseException:
     pass
 
 
