@@ -1,12 +1,4 @@
-from rapidfuzz.distance import Hamming_cpp, Hamming_py
-from ..common import GenericScorer
-
-
-def get_scorer_flags(s1, s2, **kwargs):
-    return {"maximum": max(len(s1), len(s2)), "symmetric": True}
-
-
-Hamming = GenericScorer(Hamming_py, Hamming_cpp, get_scorer_flags)
+from tests.distance.common import Hamming
 
 
 def test_basic():
